# [1.3.0](https://gitlab.com/explody/tin/compare/v1.2.3...v1.3.0) (2021-09-29)


### New

* accept a TinConfig when instantiating TinApi ([41f2ad1](https://gitlab.com/explody/tin/commit/41f2ad1aa421b2e226e8fb8f2013d2d86341b4f7))

## [1.2.3](https://gitlab.com/explody/tin/compare/v1.2.2...v1.2.3) (2021-09-27)


### Fix

* allow unset credentials ([386279b](https://gitlab.com/explody/tin/commit/386279bb63d869c4604172afe1304fff1a80e111))

## [1.2.2](https://gitlab.com/explody/tin/compare/v1.2.1...v1.2.2) (2021-09-26)


### Fix

* Fixed dependencies for flit ([a80fde0](https://gitlab.com/explody/tin/commit/a80fde095cd34bb59846fe42282649b37593ecaa))

## [1.2.1](https://gitlab.com/explody/tin/compare/v1.2.0...v1.2.1) (2021-09-24)


### Build

* remove api linting during test ([d732b6d](https://gitlab.com/explody/tin/commit/d732b6db3676afa5398d41edc4b5189ca68bc992))

### Fix

* credentials from env ([456790b](https://gitlab.com/explody/tin/commit/456790b130bd445e75d96eae1c8968d21ab967e2))

# [1.2.0](https://gitlab.com/explody/tin/compare/v1.1.3...v1.2.0) (2021-09-23)


### Fix

* removing api files ([453ba28](https://gitlab.com/explody/tin/commit/453ba281e90f9a3619619b6fa4f69844a8216955))

### New

* Support environment var prefixing ([76c0694](https://gitlab.com/explody/tin/commit/76c0694513741cd4a4a231e028f55010b788b1e5))

## [1.1.3](https://gitlab.com/explody/tin/compare/v1.1.2...v1.1.3) (2021-09-15)


### Fix

* version bump without breaking sem-ver ([10c22a3](https://gitlab.com/explody/tin/commit/10c22a398d1dc63cdf5e1357bd8e884a562f2e49))

## [1.1.2](https://gitlab.com/explody/tin/compare/v1.1.1...v1.1.2) (2021-09-15)


### Doc

* update readme ([657718a](https://gitlab.com/explody/tin/commit/657718a9210e4dc825d9585c8595944437e4569f))

### Fix

* readme and sem-ver ([57367e4](https://gitlab.com/explody/tin/commit/57367e45e238ea55e705239d1bc88e53c40df164))

## [1.1.1](https://gitlab.com/explody/tin/compare/v1.1.0...v1.1.1) (2021-09-15)


### Build

* install @semantic-release/git ([9533e21](https://gitlab.com/explody/tin/commit/9533e2125f57e38ac0f4f2518c4371709e481a4a))
* releaserc was pointing to the wrong branch ([2b377e7](https://gitlab.com/explody/tin/commit/2b377e7ebbc627a5edf264f4b458e0e044239e6b))
* setup.cfg [skip ci] ([38a3860](https://gitlab.com/explody/tin/commit/38a386022d6003cfdcc3ea7a8fccdcab87e2286c))

### Fix

* aligning version number ([885d4a6](https://gitlab.com/explody/tin/commit/885d4a64abe749e7d86bdc4bd83f95b5c3e7f2ea))
* moving API files to their own repo ([f1af2ff](https://gitlab.com/explody/tin/commit/f1af2ffec5a778389f30b6442d7df2c75dfca63e))
* version bump for pypi ([37e3f2b](https://gitlab.com/explody/tin/commit/37e3f2baf9192f0db06ccd1d709a9a2e736eff2c))
